@@ -306,6 +306,7 @@ def main(prog_or_class, singleton = SINGLETON_NOT_SINGLETON, multiproc_logging =
             exit_code = int(ret)
     except SystemExit, e:
         exit_code = e.code
+        exit_message = str(e) or exit_message
     except BaseException, e:
         errinfo = traceback.format_exc()
         logger.critical(errinfo)
@@ -330,7 +331,7 @@ def main(prog_or_class, singleton = SINGLETON_NOT_SINGLETON, multiproc_logging =
             logger.info('Sending error notification.')
             prog.send_error(exit_code, exit_message, errinfo)
         except:
-            logger.error(trackback.format_exc())
+            logger.error(traceback.format_exc())
             logger.error('Cant send notification.')
             
     prog.exit(exit_code, exit_message)
